//#include "softdevice_handler.h"
#include "sdk_config.h"
#include "nordic_common.h"
#include "nrf.h"
#include "nrf_drv_spi.h"
#include "nrf_gpio.h"
#include "nrf_delay.h"
#include "lis2dh12.h"
#include "ratio_dev.h"
#include "SEGGER_RTT.h"
#include <assert.h>

#define LIS2DH12_SPI_INSTANCE  1
static const nrf_drv_spi_t lis2dh12_spi = NRF_DRV_SPI_INSTANCE(LIS2DH12_SPI_INSTANCE);
static volatile bool lis2dh12_spi_xfer_done;

#define WRITE 0
#define READ  1

static unsigned char test_data[] =
{
		WRITE, 0x21 | 0x00,
		WRITE, 0x22 | 0x00,
		WRITE, 0x23 | 0x80,
		WRITE, 0x20 | 0x47,
		READ,  0x27,
		READ,  0x28,
		READ,  0x29,
		READ,  0x2A,
		READ,  0x2B,
		READ,  0x2C,
		READ,  0x2D,
		READ,  0x28,
		READ,  0x29,
		READ,  0x2A,
		READ,  0x2B,
		READ,  0x2C,
		READ,  0x2D,
		WRITE, 0x23 | 0x82,
		READ,  0x27,
		READ,  0x28,
		READ,  0x29,
		READ,  0x2A,
		READ,  0x2B,
		READ,  0x2C,
		READ,  0x2D,
		READ,  0x28,
		READ,  0x29,
		READ,  0x2A,
		READ,  0x2B,
		READ,  0x2C,
		READ,  0x2D,
};

static unsigned char rx_data[7];

static void lis2dh12_spi_event_handler(nrf_drv_spi_evt_t const * p_event, void * p)
{
	lis2dh12_spi_xfer_done = true;

	for(uint8_t i = 0; i<7; i++) {
		if(rx_data[i] != 0)
		SEGGER_RTT_printf(0, "data\r\n");
	}
}

void lis2dh12_write(unsigned char data)
{
	int err = 0;
	lis2dh12_spi_xfer_done = false;

	err = nrf_drv_spi_transfer(&lis2dh12_spi, &data, 1, rx_data, 7);
	APP_ERROR_CHECK(err);

	while (!lis2dh12_spi_xfer_done) {
	        //sd_app_evt_wait();
	}
	nrf_delay_us(90000);
	//nrf_delay_us(2000000);

}

void lis2dh12_pinout_setup()
{
	int err_code;
    nrf_drv_spi_config_t spi_config =
    {
        .sck_pin        = 25,
        .mosi_pin       = 24,
        .miso_pin       = 23,
        .ss_pin         = 19,
        .irq_priority   = SPI_DEFAULT_CONFIG_IRQ_PRIORITY,
        .orc            = 0xFF,
        .frequency      = NRF_SPI_FREQ_250K,
        .mode           = NRF_DRV_SPI_MODE_3,
        .bit_order      = NRF_DRV_SPI_BIT_ORDER_MSB_FIRST
    };

   err_code = nrf_drv_spi_init(&lis2dh12_spi, &spi_config, lis2dh12_spi_event_handler, NULL);
   APP_ERROR_CHECK(err_code);


}

void lis2dh12_init()
{
	int i;
	lis2dh12_pinout_setup();
	for(i = 0; i < sizeof(test_data); i+=2)
	{

		switch(test_data[i])
		{
			case WRITE:
				lis2dh12_write(test_data[i+1]);
				break;
			case READ:
				lis2dh12_write(test_data[i+1]);
				break;
			default:
				break;

		}
	}
}
